"""game.py - a context for running a game session or level

Simple example with a spritefx.
"""

import pygame

import clock
import context
import hudlight
import hudthemes
import settings
import spritefx
import tweening


__version__ = '3.0.0'
__author__ = 'Gummbum, (c) 2017'
__vernum__ = tuple(int(s) for s in __version__.split('.'))


class Game(context.Context):
    def __init__(self):
        context.Context.__init__(self, clock.FixedDriver(self.update, settings.time_step))
        self.draw_sched = self.clock.new_schedule(self.draw, settings.draw_step, keep_history=True)

        self.bgcolor = pygame.Color(0, 0, 0)

        self.sprites = []

        self.hud = hudlight.HUD(**hudthemes.HUD_THEMES['default'])
        self.hud.add('level', 'Level 1')
        self.hud.add('fps', 'FPS {:0.0f}', self.draw_sched.per_second(), callback=self.draw_sched.per_second)
        self.clock.new_schedule(self.hud.update, 0.33)

    def enter(self):
        # see context.Context
        spritefx.clear()
        s = spritefx.TextSprite('Press Escape', settings.screen_rect.center, theme_name='game', anchor='center', use_interp=False)
        s.spin_effect(start_angle=0, end_angle=360, duration=1.0, tween_function=tweening.ease_out_quad)
        s.scale_effect(start_scale=0.2, end_scale=1.0, duration=1.5, tween_function=tweening.ease_out_quad)
        s.drifty_effect(start_y=s.y - 200, end_y=s.y, duration=1.5, tween_function=tweening.ease_out_quad)
        s.driftx_effect(start_x=s.x - 200, end_x=s.x, duration=1.0, tween_function=tweening.ease_out_quad)
        self.sprites.append(s)

    def exit(self):
        # see context.Context
        spritefx.clear()

    def suspend(self):
        # see context.Context
        pass

    def resume(self):
        # see context.Context
        pass

    def quit_context(self):
        self.pop()

    def update(self, dt):
        self.get_events()
        spritefx.update_tweens(dt)

    def draw(self, sched):
        screen = settings.screen
        screen.fill(self.bgcolor)
        for s in self.sprites:
            s.draw(screen)
        self.hud.draw(screen)
        pygame.display.flip()

    def on_key_down(self, unicode, key, mod):
        # see context.Context.get_events()
        if key == pygame.K_ESCAPE:
            self.quit_context()

    def on_quit(self):
        # see context.Context.get_events()
        self.quit_context()
