"""mainmenu.py - a context for running the application's main menu
"""

import pygame

import clock
import context
import credits
import game
import pygametext
import settings


__version__ = '3.0.0'
__author__ = 'Gummbum, (c) 2017'
__vernum__ = tuple(int(s) for s in __version__.split('.'))


class ClickButton(pygame.sprite.Sprite):
    def __init__(self, text_img, y, action):
        self.image = text_img
        self.rect = text_img.get_rect(y=y, centerx=settings.screen_rect.centerx)
        self.action = action
    
    def click(self, mouse_pos):
        if self.rect.collidepoint(mouse_pos):
            self.action()


class MainMenu(context.Context):
    def __init__(self):
        context.Context.__init__(self, clock.FixedDriver(self.update, settings.time_step))
        self.clock.new_schedule(self.draw, 1.0 / 30.0)

        self.bgcolor = pygame.Color('darkgreen')
    
    def enter(self):
        # see context.Context
        font_info = settings.font_info.mainmenu
        font = pygametext.getfont(font_info.fontname, font_info.fontsize)
        screen_centery = settings.screen_rect.centery
        text_height = font.get_height()
        font_color = pygame.Color(font_info.color)
        
        self.buttons = []
        
        n = -1.5
        # text_img = font.render('PLAY GAME', True, font_color)
        text_img = pygametext.getsurf('PLAY GAME', **settings.font_themes['mainmenu'])
        self.buttons.append(ClickButton(
            text_img, screen_centery + n * text_height, self.action_play_game))
        
        n += 1
        # text_img = font.render('CREDITS', True, font_color)
        text_img = pygametext.getsurf('CREDITS', **settings.font_themes['mainmenu'])
        self.buttons.append(ClickButton(
            text_img, screen_centery + n * text_height, self.action_show_credits))
        
        n += 1
        # text_img = font.render('QUIT GAME', True, font_color)
        text_img = pygametext.getsurf('QUIT GAME', **settings.font_themes['mainmenu'])
        self.buttons.append(ClickButton(
            text_img, screen_centery + n * text_height, self.action_quit_game))
    
    def exit(self):
        # see context.Context
        pass

    def suspend(self):
        # see context.Context
        pass

    def resume(self):
        # see context.Context
        pass

    def quit_context(self):
        self.pop()

    def action_play_game(self):
        self.push(game.Game())
    
    def action_show_credits(self):
        self.push(credits.Credits())
    
    def action_quit_game(self):
        self.quit_context()
    
    def update(self, dt):
        self.get_events()
    
    def draw(self, sched):
        screen = settings.screen
        screen.fill(self.bgcolor)
        for b in self.buttons:
            screen.blit(b.image, b.rect)
        pygame.display.flip()
    
    def on_mouse_button_down(self, pos, button):
        for b in self.buttons:
            b.click(pos)
